==> Office365-REST-Python-Client-2.1.6.post2.tar.gz: Office365-REST-Python-Client-2.1.6.post2/office365/sharepoint/attachmentfile_collection.py <==
from office365.runtime.client_object_collection import ClientObjectCollection
from office365.runtime.client_query import ServiceOperationQuery
from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
from office365.sharepoint.attachmentfile import AttachmentFile
from office365.sharepoint.attachmentfile_creation_information import AttachmentfileCreationInformation
from office365.sharepoint.file import File


class AttachmentfileCollection(ClientObjectCollection):
    """Represents a collection of AttachmentFile resources."""

    def __init__(self, context, resource_path=None):
        super(AttachmentfileCollection, self).__init__(context, AttachmentFile, resource_path)

    def add(self, attachment_file_information):
        """Creates an attachment"""
        if isinstance(attachment_file_information, dict):
            attachment_file_information = AttachmentfileCreationInformation(
                attachment_file_information.get('filename'),
                attachment_file_information.get('content')
            )

        file_new = File(self.context)
        qry = ServiceOperationQuery(self,
                                    "add",
                                    {
                                        "filename": attachment_file_information.filename,
                                    },
                                    attachment_file_information.content)
        self.context.add_query(qry, file_new)
        self.add_child(file_new)
        return file_new

    def get_by_filename(self, filename):
        """Retrieve Attachment file object by filename"""
        return AttachmentFile(self.context,
                              ResourcePathServiceOperation("GetByFileName", [filename], self.resourcePath))

==> Office365-REST-Python-Client-2.1.9.tar.gz: Office365-REST-Python-Client-2.1.9/office365/sharepoint/attachmentfile_collection.py <==
from office365.runtime.client_object_collection import ClientObjectCollection
from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
from office365.runtime.serviceOperationQuery import ServiceOperationQuery
from office365.sharepoint.attachmentfile import AttachmentFile
from office365.sharepoint.attachmentfile_creation_information import AttachmentfileCreationInformation
from office365.sharepoint.file import File


class AttachmentFileCollection(ClientObjectCollection):
    """Represents a collection of AttachmentFile resources."""

    def __init__(self, context, resource_path=None):
        super(AttachmentFileCollection, self).__init__(context, AttachmentFile, resource_path)

    def add(self, attachment_file_information):
        """Creates an attachment"""
        if isinstance(attachment_file_information, dict):
            attachment_file_information = AttachmentfileCreationInformation(
                attachment_file_information.get('filename'),
                attachment_file_information.get('content')
            )

        target_file = File(self.context)
        self.add_child(target_file)
        qry = ServiceOperationQuery(self,
                                    "add",
                                    {
                                        "filename": attachment_file_information.filename,
                                    },
                                    attachment_file_information.content,
                                    None,
                                    target_file)
        self.context.add_query(qry)
        return target_file

    def get_by_filename(self, filename):
        """Retrieve Attachment file object by filename"""
        return AttachmentFile(self.context,
                              ResourcePathServiceOperation("GetByFileName", [filename], self.resource_path))
